@@ -4,6 +4,7 @@ import ast
 import cgen as c
 from collections import OrderedDict
 import math
+import numpy as np
 import random
 from .grid import GridCode
 
@@ -60,6 +61,7 @@ class RandomNode(IntrinsicNode):
                   'uniform': 'parcels_uniform',
                   'randint': 'parcels_randint',
                   'normalvariate': 'parcels_normalvariate',
+                  'expovariate': 'parcels_expovariate',
                   'seed': 'parcels_seed'}
 
     def __getattr__(self, attr):
@@ -308,14 +310,23 @@ class KernelGenerator(ast.NodeVisitor):
         supported."""
         pointer_args = False
         if isinstance(node.func, PrintNode):
-            if hasattr(node.args[0], 's'):
+            # Write our own Print parser because Python3-AST does not seem to have one
+            if isinstance(node.args[0], ast.Str):
                 node.ccode = str(c.Statement('printf("%s\\n")' % (node.args[0].s)))
-                return
-            if isinstance(node.args[0], ast.BinOp):
+            elif isinstance(node.args[0], ast.Name):
+                node.ccode = str(c.Statement('printf("%%f\\n", %s)' % (node.args[0].id)))
+            elif isinstance(node.args[0], ast.BinOp):
                 if hasattr(node.args[0].right, 'ccode'):
                     args = node.args[0].right.ccode
                 elif hasattr(node.args[0].right, 'elts'):
-                    args = [a.ccode for a in node.args[0].right.elts]
+                    args = []
+                    for a in node.args[0].right.elts:
+                        if hasattr(a, 'ccode'):
+                            args.append(a.ccode)
+                        elif hasattr(a, 'id'):
+                            args.append(a.id)
+                else:
+                    args = []
                 s = 'printf("%s\\n"' % node.args[0].left.s
                 if isinstance(args, str):
                     s = s + (", %s)" % args)
@@ -324,7 +335,8 @@ class KernelGenerator(ast.NodeVisitor):
                         s = s + (", %s" % arg)
                     s = s + ")"
                 node.ccode = str(c.Statement(s))
-                return
+            else:
+                raise RuntimeError("This print statement is not supported in Python3 version of Parcels")
         else:
             for a in node.args:
                 self.visit(a)
@@ -398,9 +410,14 @@ class KernelGenerator(ast.NodeVisitor):
             self.visit(b)
         for b in node.orelse:
             self.visit(b)
-        body = c.Block([b.ccode for b in node.body])
+        # field evals are replaced by a tmp variable is added to the stack.
+        # Here it means field evals passes from node.test to node.body. We take it out manually
+        fieldInTestCount = node.test.ccode.count('tmp')
+        body0 = c.Block([b.ccode for b in node.body[:fieldInTestCount]])
+        body = c.Block([b.ccode for b in node.body[fieldInTestCount:]])
         orelse = c.Block([b.ccode for b in node.orelse]) if len(node.orelse) > 0 else None
-        node.ccode = c.If(node.test.ccode, body, orelse)
+        ifcode = c.If(node.test.ccode, body, orelse)
+        node.ccode = c.Block([body0, ifcode])
 
     def visit_Compare(self, node):
         self.visit(node.left)
@@ -589,7 +606,10 @@ class LoopGenerator(object):
         # Generate type definition for particle type
         vdecl = []
         for v in self.ptype.variables:
-            vdecl.append(c.POD(v.dtype, v.name))
+            if v.dtype == np.uint64:
+                vdecl.append(c.Pointer(c.POD(np.void, v.name))) 
+            else:
+                vdecl.append(c.POD(v.dtype, v.name))
 
         ccode += [str(c.Typedef(c.GenerableStruct("", vdecl, declname=self.ptype.name)))]
 
