@@ -2,6 +2,7 @@ from parcels.loggers import logger
 import numpy as np
 from ctypes import Structure, c_int, c_float, c_double, POINTER, cast, c_void_p, pointer
 from enum import IntEnum
+import datetime
 
 __all__ = ['GridCode', 'RectilinearZGrid', 'RectilinearSGrid', 'CurvilinearZGrid', 'CurvilinearSGrid', 'CGrid']
 
@@ -37,6 +38,10 @@ class Grid(object):
             logger.warning_once("Casting time data to np.float64")
             self.time = self.time.astype(np.float64)
         self.time_origin = time_origin
+        if self.time_origin:
+            if isinstance(self.time_origin, datetime.datetime):
+                self.time_origin = np.datetime64(self.time_origin)
+            assert isinstance(self.time_origin, np.datetime64), 'If defined, time_origin must be a datetime.datetime or a np.datetime64'
         self.mesh = mesh
         self.cstruct = None
         self.cell_edge_sizes = {}
@@ -92,7 +97,9 @@ class Grid(object):
         return lon
 
     def advancetime(self, grid_new):
-        grid_new.time = grid_new.time + (grid_new.time_origin - self.time_origin) / np.timedelta64(1, 's')
+        assert isinstance(grid_new.time_origin, type(self.time_origin)), 'time_origin of new and old grids must be either both None or both a date'
+        if self.time_origin:
+            grid_new.time = grid_new.time + (grid_new.time_origin - self.time_origin) / np.timedelta64(1, 's')
         if len(grid_new.time) is not 1:
             raise RuntimeError('New FieldSet needs to have only one snapshot')
         if grid_new.time > self.time[-1]:  # forward in time, so appending at end
@@ -114,7 +121,7 @@ class Grid(object):
 
     def computeTimeChunk(self, f, time, signdt):
         nextTime_loc = np.infty * signdt
-        if self.update_status == 'no_update':
+        if self.update_status == 'not_updated':
             if self.ti >= 0:
                 if signdt >= 0 and ((time < self.time[0] and self.ti > 0)
                    or (time > self.time[2] and self.ti < len(self.time_full)-3)):
@@ -122,19 +129,21 @@ class Grid(object):
                 elif signdt >= 0 and time >= self.time[1] and self.ti < len(self.time_full)-3:
                     self.ti += 1
                     self.time = self.time_full[self.ti:self.ti+3]
-                    self.update_status = 'update'
+                    self.update_status = 'updated'
                 elif signdt == -1 and time <= self.time[1] and self.ti > 0:
                     self.ti -= 1
                     self.time = self.time_full[self.ti:self.ti+3]
-                    self.update_status = 'update'
+                    self.update_status = 'updated'
             if self.ti == -1:
                 self.time = self.time_full
                 self.ti, _ = f.time_index(time)
                 if self.ti > 0 and signdt == -1:
-                    self.ti = self.ti-2 if len(self.time_full)-1 else self.ti-1
+                    self.ti -= 1
+                if self.ti >= len(self.time_full) - 2:
+                    self.ti = len(self.time_full) - 3
                 self.time = self.time_full[self.ti:self.ti+3]
                 self.tdim = 3
-                self.update_status = 'first_update'
+                self.update_status = 'first_updated'
             if signdt >= 0 and self.ti < len(self.time_full)-3:
                 nextTime_loc = self.time[2]
             elif signdt == -1 and self.ti > 0:
@@ -199,7 +208,7 @@ class RectilinearZGrid(RectilinearGrid):
     :param depth: Vector containing the vertical coordinates of the grid, which are z-coordinates.
            The depth of the different layers is thus constant.
     :param time: Vector containing the time coordinates of the grid
-    :param time_origin: Time origin of the time axis
+    :param time_origin: Time origin (datetime or np.datetime64 object) of the time axis
     :param mesh: String indicating the type of mesh coordinates and
            units used during velocity interpolation:
 
@@ -208,7 +217,7 @@ class RectilinearZGrid(RectilinearGrid):
            2. flat: No conversion, lat/lon are assumed to be in m.
     """
 
-    def __init__(self, lon, lat, depth=None, time=None, time_origin=0, mesh='flat'):
+    def __init__(self, lon, lat, depth=None, time=None, time_origin=None, mesh='flat'):
         RectilinearGrid.__init__(self, lon, lat, time, time_origin, mesh)
         if isinstance(depth, np.ndarray):
             assert(len(depth.shape) == 1), 'depth is not a vector'
@@ -236,7 +245,7 @@ class RectilinearSGrid(RectilinearGrid):
            the number of the layer and the time is depth is a 4D array.
            depth array is either a 4D array[xdim][ydim][zdim][tdim] or a 3D array[xdim][ydim[zdim].
     :param time: Vector containing the time coordinates of the grid
-    :param time_origin: Time origin of the time axis
+    :param time_origin: Time origin (datetime or np.datetime64 object) of the time axis
     :param mesh: String indicating the type of mesh coordinates and
            units used during velocity interpolation:
 
@@ -245,7 +254,7 @@ class RectilinearSGrid(RectilinearGrid):
            2. flat: No conversion, lat/lon are assumed to be in m.
     """
 
-    def __init__(self, lon, lat, depth, time=None, time_origin=0, mesh='flat'):
+    def __init__(self, lon, lat, depth, time=None, time_origin=None, mesh='flat'):
         RectilinearGrid.__init__(self, lon, lat, time, time_origin, mesh)
         assert(isinstance(depth, np.ndarray) and len(depth.shape) in [3, 4]), 'depth is not a 3D or 4D numpy array'
 
@@ -269,7 +278,7 @@ class RectilinearSGrid(RectilinearGrid):
 
 class CurvilinearGrid(Grid):
 
-    def __init__(self, lon, lat, time=None, time_origin=0, mesh='flat'):
+    def __init__(self, lon, lat, time=None, time_origin=None, mesh='flat'):
         assert(isinstance(lon, np.ndarray) and len(lon.squeeze().shape) == 2), 'lon is not a 2D numpy array'
         assert(isinstance(lat, np.ndarray) and len(lat.squeeze().shape) == 2), 'lat is not a 2D numpy array'
         assert (isinstance(time, np.ndarray) or not time), 'time is not a numpy array'
@@ -328,7 +337,7 @@ class CurvilinearZGrid(CurvilinearGrid):
     :param depth: Vector containing the vertical coordinates of the grid, which are z-coordinates.
            The depth of the different layers is thus constant.
     :param time: Vector containing the time coordinates of the grid
-    :param time_origin: Time origin of the time axis
+    :param time_origin: Time origin (datetime or np.datetime64 object) of the time axis
     :param mesh: String indicating the type of mesh coordinates and
            units used during velocity interpolation:
 
@@ -337,7 +346,7 @@ class CurvilinearZGrid(CurvilinearGrid):
            2. flat: No conversion, lat/lon are assumed to be in m.
     """
 
-    def __init__(self, lon, lat, depth=None, time=None, time_origin=0, mesh='flat'):
+    def __init__(self, lon, lat, depth=None, time=None, time_origin=None, mesh='flat'):
         CurvilinearGrid.__init__(self, lon, lat, time, time_origin, mesh)
         if isinstance(depth, np.ndarray):
             assert(len(depth.shape) == 1), 'depth is not a vector'
@@ -364,7 +373,7 @@ class CurvilinearSGrid(CurvilinearGrid):
            the number of the layer and the time is depth is a 4D array.
            depth array is either a 4D array[xdim][ydim][zdim][tdim] or a 3D array[xdim][ydim[zdim].
     :param time: Vector containing the time coordinates of the grid
-    :param time_origin: Time origin of the time axis
+    :param time_origin: Time origin (datetime or np.datetime64 object) of the time axis
     :param mesh: String indicating the type of mesh coordinates and
            units used during velocity interpolation:
 
@@ -373,7 +382,7 @@ class CurvilinearSGrid(CurvilinearGrid):
            2. flat: No conversion, lat/lon are assumed to be in m.
     """
 
-    def __init__(self, lon, lat, depth, time=None, time_origin=0, mesh='flat'):
+    def __init__(self, lon, lat, depth, time=None, time_origin=None, mesh='flat'):
         CurvilinearGrid.__init__(self, lon, lat, time, time_origin, mesh)
         assert(isinstance(depth, np.ndarray) and len(depth.shape) in [3, 4]), 'depth is not a 4D numpy array'
 
