@@ -49,8 +49,11 @@ class ParticleSet(object):
 
         time = time.tolist() if isinstance(time, np.ndarray) else time
         time = [time] * len(lat) if not isinstance(time, list) else time
-        time = [t.total_seconds() if isinstance(t, delta) else t for t in time]
-        time = [((np.datetime64(t) - fieldset.U.grid.time_origin) / np.timedelta64(1, 's')) if isinstance(t, datetime) else t for t in time]
+        time = [np.datetime64(t) if isinstance(t, datetime) else t for t in time]
+        self.time_origin = fieldset.U.grid.time_origin
+        if len(time) > 0 and isinstance(time[0], np.timedelta64) and not self.time_origin:
+            raise NotImplementedError('If fieldset.U.grid.time_origin is not a date, time of a particle must be a double')
+        time = [((t - self.time_origin) / np.timedelta64(1, 's')) if isinstance(t, np.datetime64) else t for t in time]
 
         assert len(lon) == len(time)
 
@@ -70,7 +73,6 @@ class ParticleSet(object):
         self.particles = np.empty(size, dtype=pclass)
         self.ptype = pclass.getPType()
         self.kernel = None
-        self.time_origin = fieldset.U.grid.time_origin
 
         if self.ptype.uses_jit:
             # Allocate underlying data for C-allocated particles
@@ -257,7 +259,11 @@ class ParticleSet(object):
         if isinstance(endtime, delta):
             raise RuntimeError('endtime must be either a datetime or a double')
         if isinstance(endtime, datetime):
-            endtime = (endtime - self.time_origin).total_seconds()
+            endtime = np.datetime64(endtime)
+        if isinstance(endtime, np.datetime64):
+            if not self.time_origin:
+                raise NotImplementedError('If fieldset.U.grid.time_origin is not a date, execution endtime must be a double')
+            endtime = (endtime - self.time_origin) / np.timedelta64(1, 's')
         if isinstance(runtime, delta):
             runtime = runtime.total_seconds()
         if isinstance(dt, delta):
@@ -311,9 +317,9 @@ class ParticleSet(object):
         if self.repeatdt:
             next_prelease = self.repeat_starttime + (abs(time - self.repeat_starttime) // self.repeatdt + 1) * self.repeatdt * np.sign(dt)
         else:
-            next_prelease = np.infty * np.sign(dt)
-        next_output = time + outputdt * np.sign(dt)
-        next_movie = time + moviedt * np.sign(dt)
+            next_prelease = np.infty if dt > 0 else - np.infty
+        next_output = time + outputdt if dt > 0 else time - outputdt
+        next_movie = time + moviedt if dt > 0 else time - moviedt
         next_input = self.fieldset.computeTimeChunk(time, np.sign(dt))
 
         tol = 1e-12
@@ -324,9 +330,12 @@ class ParticleSet(object):
                 time = max(next_prelease, next_input, next_output, next_movie, endtime)
             self.kernel.execute(self, endtime=time, dt=dt, recovery=recovery, output_file=output_file)
             if abs(time-next_prelease) < tol:
-                self.add(ParticleSet(fieldset=self.fieldset, time=time, lon=self.repeatlon,
-                                     lat=self.repeatlat, depth=self.repeatdepth,
-                                     pclass=self.repeatpclass))
+                pset_new = ParticleSet(fieldset=self.fieldset, time=time, lon=self.repeatlon,
+                                       lat=self.repeatlat, depth=self.repeatdepth,
+                                       pclass=self.repeatpclass)
+                for p in pset_new:
+                    p.dt = dt
+                self.add(pset_new)
                 next_prelease += self.repeatdt * np.sign(dt)
             if abs(time-next_output) < tol:
                 if output_file:
@@ -371,7 +380,9 @@ class ParticleSet(object):
         if isinstance(show_time, datetime):
             show_time = np.datetime64(show_time)
         if isinstance(show_time, np.datetime64):
-            show_time = (show_time - self.fieldset.U.grid.time_origin) / np.timedelta64(1, 's')
+            if not self.time_origin:
+                raise NotImplementedError('If fieldset.U.grid.time_origin is not a date, showtime cannot be a date in particleset.show()')
+            show_time = (show_time - self.time_origin) / np.timedelta64(1, 's')
         if isinstance(show_time, delta):
             show_time = show_time.total_seconds()
         if np.isnan(show_time):
@@ -393,7 +404,7 @@ class ParticleSet(object):
             lonW = nearest_index(self.fieldset.U.lon, domain[3])
         else:
             latN, latS, lonE, lonW = (-1, 0, -1, 0)
-        if field is not 'vector':
+        if field is not 'vector' and not land:
             plt.ion()
             plt.clf()
             if particles:
@@ -402,34 +413,24 @@ class ParticleSet(object):
                 axes = plt.gca()
                 axes.set_xlim([self.fieldset.U.lon[lonW], self.fieldset.U.lon[lonE]])
                 axes.set_ylim([self.fieldset.U.lat[latS], self.fieldset.U.lat[latN]])
-                namestr = ''
-                time_origin = self.fieldset.U.grid.time_origin
             else:
                 if not isinstance(field, Field):
                     field = getattr(self.fieldset, field)
                 field.show(with_particles=True, show_time=show_time, vmin=vmin, vmax=vmax)
-                namestr = field.name
-                time_origin = field.grid.time_origin
             xlbl = 'Zonal distance [m]' if type(self.fieldset.U.units) is UnitConverter else 'Longitude [degrees]'
             ylbl = 'Meridional distance [m]' if type(self.fieldset.U.units) is UnitConverter else 'Latitude [degrees]'
             plt.xlabel(xlbl)
             plt.ylabel(ylbl)
         elif Basemap is None:
             logger.info("Visualisation is not possible. Basemap not found.")
-            time_origin = self.fieldset.U.grid.time_origin
         else:
-            time_origin = self.fieldset.U.grid.time_origin
             self.fieldset.computeTimeChunk(show_time, 1)
             (idx, periods) = self.fieldset.U.time_index(show_time)
             show_time -= periods*(self.fieldset.U.time[-1]-self.fieldset.U.time[0])
-            U = np.array(self.fieldset.U.temporal_interpolate_fullfield(idx, show_time))
-            V = np.array(self.fieldset.V.temporal_interpolate_fullfield(idx, show_time))
             lon = self.fieldset.U.lon
             lat = self.fieldset.U.lat
             lon = lon[lonW:lonE]
             lat = lat[latS:latN]
-            U = U[latS:latN, lonW:lonE]
-            V = V[latS:latN, lonW:lonE]
 
             # configuring plot
             lat_median = np.median(lat)
@@ -439,37 +440,43 @@ class ParticleSet(object):
                         resolution='h', area_thresh=100,
                         llcrnrlon=lon[0], llcrnrlat=lat[0],
                         urcrnrlon=lon[-1], urcrnrlat=lat[-1])
-            if land:
-                m.drawcoastlines()
-                m.fillcontinents(color='burlywood')
             parallels = np.arange(lat[0], lat[-1], abs(lat[0]-lat[-1])/5)
             parallels = np.around(parallels, 2)
             m.drawparallels(parallels, labels=[1, 0, 0, 0])
             meridians = np.arange(lon[0], lon[-1], abs(lon[0]-lon[-1])/5)
             meridians = np.around(meridians, 2)
             m.drawmeridians(meridians, labels=[0, 0, 0, 1])
+            if land:
+                m.drawcoastlines()
+                m.fillcontinents(color='burlywood')
+            if field is 'vector':
+                # formating velocity data for quiver plotting
+                U = np.array(self.fieldset.U.temporal_interpolate_fullfield(idx, show_time))
+                V = np.array(self.fieldset.V.temporal_interpolate_fullfield(idx, show_time))
+                U = U[latS:latN, lonW:lonE]
+                V = V[latS:latN, lonW:lonE]
+                U = np.array([U[y, x] for x in range(len(lon)) for y in range(len(lat))])
+                V = np.array([V[y, x] for x in range(len(lon)) for y in range(len(lat))])
+                speed = np.sqrt(U**2 + V**2)
+                normU = U/speed
+                normV = V/speed
+                x = np.repeat(lon, len(lat))
+                y = np.tile(lat, len(lon))
 
-            # formating velocity data for quiver plotting
-            U = np.array([U[y, x] for x in range(len(lon)) for y in range(len(lat))])
-            V = np.array([V[y, x] for x in range(len(lon)) for y in range(len(lat))])
-            speed = np.sqrt(U**2 + V**2)
-            normU = U/speed
-            normV = V/speed
-            x = np.repeat(lon, len(lat))
-            y = np.tile(lat, len(lon))
-
-            # plotting velocity vector field
-            vecs = m.quiver(x, y, normU, normV, speed, cmap=plt.cm.gist_ncar, clim=[vmin, vmax], scale=50, latlon=True)
-            m.colorbar(vecs, "right", size="5%", pad="2%")
+                # plotting velocity vector field
+                vecs = m.quiver(x, y, normU, normV, speed, cmap=plt.cm.gist_ncar, clim=[vmin, vmax], scale=50, latlon=True)
+                m.colorbar(vecs, "right", size="5%", pad="2%")
+            elif field is not None:
+                logger.warning('Plotting of both a field and land=True is not supported in this version of Parcels')
             # plotting particle data
             if particles:
                 xs, ys = m(plon, plat)
                 m.scatter(xs, ys, color='black')
 
-        if time_origin is 0:
+        if not self.time_origin:
             timestr = ' after ' + str(delta(seconds=show_time)) + ' hours'
         else:
-            date_str = str(time_origin + np.timedelta64(int(show_time), 's'))
+            date_str = str(self.time_origin + np.timedelta64(int(show_time), 's'))
             timestr = ' on ' + date_str[:10] + ' ' + date_str[11:19]
 
         if particles:
@@ -478,12 +485,12 @@ class ParticleSet(object):
             elif field is 'vector':
                 plt.title('Particles and velocity field' + timestr)
             else:
-                plt.title('Particles and '+namestr + timestr)
+                plt.title('Particles and '+field.name + timestr)
         else:
             if field is 'vector':
                 plt.title('Velocity field' + timestr)
             else:
-                plt.title(namestr + timestr)
+                plt.title(field.name + timestr)
 
         if savefile is None:
             plt.show()
